==> growingio-graphql-javasdk_2.12-0.0.1-sources.jar: io/growing/graphql/resolver/impl/$UserProjectPermissionModulesQueryResolver.java <==
package io.growing.graphql.resolver.impl;

import com.kobylynskyi.graphql.codegen.extension.GrowingIOConfig;
import com.kobylynskyi.graphql.codegen.extension.utils.JavaCollectionUtils;
import com.kobylynskyi.graphql.codegen.extension.utils.OkHttpUtils;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLRequest;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import io.growing.graphql.resolver.*;
import io.growing.graphql.model.*;

@javax.annotation.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2020-12-22T15:45:58+0800"
)
final public class $UserProjectPermissionModulesQueryResolver implements UserProjectPermissionModulesQueryResolver {

    private GrowingIOConfig growingIOConfig;

    public $UserProjectPermissionModulesQueryResolver(GrowingIOConfig growingIOConfig) {
        this.growingIOConfig = growingIOConfig;
    }

    private $UserProjectPermissionModulesQueryResolver() {}

    @javax.validation.constraints.NotNull
    @Override
    public java.util.List<ModuleDto> userProjectPermissionModules(String projectId, String userId) throws Exception {
        UserProjectPermissionModulesQueryRequest request = new UserProjectPermissionModulesQueryRequest();
        List<String> keys = Arrays.asList("projectId", "userId");
        List<?> values = Arrays.asList(projectId, userId);
        Map<String, ?> parameters = JavaCollectionUtils.listToMap(keys, values);
        request.getInput().putAll(parameters);
        ModuleResponseProjection projection = new ModuleResponseProjection().all$(growingIOConfig.getResponseProjectionMaxDepth());
        GraphQLRequest graphQLRequest = new GraphQLRequest(request, projection);
        UserProjectPermissionModulesQueryResponse result = OkHttpUtils.executeGraphQLRemote(growingIOConfig, graphQLRequest, UserProjectPermissionModulesQueryResponse.class);
        return result.userProjectPermissionModules();
    }

}

==> growingio-graphql-javasdk_2.12-0.0.2-sources.jar: io/growing/graphql/resolver/impl/$UserProjectPermissionModulesQueryResolver.java <==
package io.growing.graphql.resolver.impl;

import com.kobylynskyi.graphql.codegen.extension.GrowingIOConfig;
import com.kobylynskyi.graphql.codegen.extension.utils.JavaCollectionUtils;
import com.kobylynskyi.graphql.codegen.extension.utils.OkHttpUtils;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLRequest;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import io.growing.graphql.resolver.*;
import io.growing.graphql.model.*;

@javax.annotation.processing.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2021-05-27T14:30:17+0800"
)
final public class $UserProjectPermissionModulesQueryResolver implements UserProjectPermissionModulesQueryResolver {

    private GrowingIOConfig growingIOConfig;

    public $UserProjectPermissionModulesQueryResolver(GrowingIOConfig growingIOConfig) {
        this.growingIOConfig = growingIOConfig;
    }

    private $UserProjectPermissionModulesQueryResolver() {}

    @javax.validation.constraints.NotNull
    @Override
    public java.util.List<ModuleDto> userProjectPermissionModules(String projectId, String userId) throws Exception {
        UserProjectPermissionModulesQueryRequest request = new UserProjectPermissionModulesQueryRequest();
        List<String> keys = Arrays.asList("projectId", "userId");
        List<?> values = Arrays.asList(projectId, userId);
        Map<String, ?> parameters = JavaCollectionUtils.listToMap(keys, values);
        request.getInput().putAll(parameters);
        ModuleResponseProjection projection = new ModuleResponseProjection().all$(growingIOConfig.getResponseProjectionMaxDepth());
        GraphQLRequest graphQLRequest = new GraphQLRequest(request, projection);
        UserProjectPermissionModulesQueryResponse result = OkHttpUtils.executeGraphQLRemote(growingIOConfig, graphQLRequest, UserProjectPermissionModulesQueryResponse.class);
        return result.userProjectPermissionModules();
    }

}
